summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJames Smith <smithjd15@gmail.com>2021-11-19 09:22:24 -0500
committerWilliam Wilgus <me.theuser@yahoo.com>2021-11-21 12:44:57 -0500
commit990c543ebcf821658a421aec3ae842bb51726072 (patch)
treed65c70dcde283fb75fad20d36dd7ae5e5bc70f31
parenta14347a6b3970cb327f6c60f308d93c88b33130d (diff)
downloadrockbox-990c543ebcf821658a421aec3ae842bb51726072.tar.gz
rockbox-990c543ebcf821658a421aec3ae842bb51726072.zip
Revert "Pictureflow: Update for tag_virt_canonicalartist."
This reverts commit 60125f6bc987f4e234610f3e23a0e45e5d9b6d6e. Reason for revert: See g#3947. Change-Id: I34bae3cf5a87a5c99b9a4e5755e1a4a69961b28a
-rw-r--r--apps/plugins/pictureflow/pictureflow.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/apps/plugins/pictureflow/pictureflow.c b/apps/plugins/pictureflow/pictureflow.c
index 7c2ad520c9..b5cef72732 100644
--- a/apps/plugins/pictureflow/pictureflow.c
+++ b/apps/plugins/pictureflow/pictureflow.c
@@ -1057,8 +1057,8 @@ static int create_album_untagged(struct tagcache_search *tcs,
draw_splashscreen(*buf, *bufsz);
draw_progressbar(0, total_count, "Searching " UNTAGGED);
- /* search tagcache for all <untagged> albums & save the canonicalartist seek pos */
- if (rb->tagcache_search(tcs, tag_virt_canonicalartist))
+ /* search tagcache for all <untagged> albums & save the albumartist seek pos */
+ if (rb->tagcache_search(tcs, tag_albumartist))
{
rb->tagcache_search_add_filter(tcs, tag_album, pf_idx.album_untagged_seek);
@@ -1161,7 +1161,7 @@ static int build_artist_index(struct tagcache_search *tcs,
/* artist names starts at beginning of buf */
pf_idx.artist_names = *buf;
- rb->tagcache_search(tcs, tag_virt_canonicalartist);
+ rb->tagcache_search(tcs, tag_albumartist);
res = get_tcs_search_res(ePFS_ARTIST, tcs, &(*buf), bufsz);
rb->tagcache_search_finish(tcs);
if (res < SUCCESS)
@@ -1268,7 +1268,7 @@ static int create_album_index(void)
draw_progressbar(j, pf_idx.album_ct, NULL);
if (pf_idx.album_index[j].artist_seek >= 0) { continue; }
- rb->tagcache_search(&tcs, tag_virt_canonicalartist);
+ rb->tagcache_search(&tcs, tag_albumartist);
rb->tagcache_search_add_filter(&tcs, tag_album, pf_idx.album_index[j].seek);
last = 0;
@@ -1602,7 +1602,7 @@ static void create_track_index(const int slide_index)
if (pf_idx.album_index[slide_index].artist_idx >= 0)
{
- rb->tagcache_search_add_filter(&tcs, tag_virt_canonicalartist,
+ rb->tagcache_search_add_filter(&tcs, tag_albumartist,
pf_idx.album_index[slide_index].artist_seek);
}
@@ -1757,7 +1757,7 @@ static bool get_albumart_for_index_from_db(const int slide_index, char *buf,
rb->tagcache_search_add_filter(&tcs, tag_album,
pf_idx.album_index[slide_index].seek);
- rb->tagcache_search_add_filter(&tcs, tag_virt_canonicalartist,
+ rb->tagcache_search_add_filter(&tcs, tag_albumartist,
pf_idx.album_index[slide_index].artist_seek);
if ( rb->tagcache_get_next(&tcs) ) {